#! /usr/bin/env python
import numpy as np
import matplotlib.pyplot as plt

pllfile = '../data/DIFF_PLL_CTRL_OUT_v2.dat'
freqfile = '../data/VCO_freq_v2.dat'


A = np.loadtxt(pllfile)
B = np.loadtxt(freqfile)

pll_ctrl = A[:,1]
freq = B[:,1]


hf = 78.95e6
lf = 78.89e6

for jj in range(len(freq)-1):
	if freq[jj] > hf and freq[jj + 1] < hf :
		highend = jj
		print jj
	if freq[jj] > lf and freq[jj + 1] < lf :
		lowend = jj
		print jj


N = 1
z = np.polyfit(freq[highend:lowend], pll_ctrl[highend:lowend], N)
print z

#p = np.poly1d([4.84295e-6, 4.84295e-6 * -7.8917e7])
p = np.poly1d(z)

plt.figure(101, figsize=(13,13))
plt.subplot(211)
plt.title('DIFF VCO calibration (2015 May 26)')
plt.plot(freq * 1e-6, pll_ctrl, '*', label='measured')
plt.plot(freq*1e-6, p(freq), '-', alpha=0.5, lw=3, color='r', label='fit')
plt.grid()
plt.xlim(freq[lowend]*1e-6, freq[highend]*1e-6)
plt.ylabel('DIFF_PLL_CTRL [counts]')
plt.xlabel('VCO frequency [MHz]')
plt.legend(loc='best')
plt.ylim(-1,1)
plt.subplot(212)
plt.plot(freq*1e-6, pll_ctrl-p(freq), '.')
plt.ylim(-0.006, 0.006)
plt.xlim(freq[lowend]*1e-6, freq[highend]*1e-6)
plt.grid()
plt.xlabel('VCO frequency [MHz]')
plt.ylabel('residuals [counts]')

plt.savefig('../figures/VCO_calibration.png', transparent=True)


#for jj in range(len(freq)):
#	if jj < lowend  and jj > highend:
#		print "%.10e %.10e"%(freq[jj], pll_ctrl[jj])

